@@ -1,9 +1,18 @@
 import logging
-import pickle
-from pickle import HIGHEST_PROTOCOL
+import sys
 
 import cloudpickle
 
+if sys.version_info < (3, 8):
+    try:
+        import pickle5 as pickle
+    except ImportError:
+        import pickle
+else:
+    import pickle
+
+
+HIGHEST_PROTOCOL = pickle.HIGHEST_PROTOCOL
 
 logger = logging.getLogger(__name__)
 
